@@ -8,6 +8,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+
 	"os"
 	"strings"
 	"sync"
@@ -15,9 +16,9 @@ import (
 
 	"github.com/godbus/dbus/v5"
 	btcommon "github.com/linuxdeepin/dde-daemon/common/bluetooth"
-	obex "github.com/linuxdeepin/go-dbus-factory/session/org.bluez.obex"
 	audio "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.audio1"
 	mpris2 "github.com/linuxdeepin/go-dbus-factory/session/org.mpris.mediaplayer2"
+	obex "github.com/linuxdeepin/go-dbus-factory/system/org.bluez.obex"
 	airplanemode "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.airplanemode1"
 	sysbt "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.bluetooth1"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.dbus"
@@ -247,8 +248,8 @@ func (b *Bluetooth) init() {
 		logger.Warning(err)
 	}
 
-	canSendFile = b.getSendFileEnable()
-	b.setPropCanSendFile(canSendFile)
+	configCanSendFile := b.getSendFileEnable()
+	b.setPropCanSendFile(canSendFile && configCanSendFile)
 
 	err = b.sysBt.State().ConnectChanged(func(hasValue bool, value uint32) {
 		if !hasValue {
@@ -267,6 +268,7 @@ func (b *Bluetooth) init() {
 
 	sysBus, err := dbus.SystemBus()
 	if err != nil {
+		logger.Warning(err)
 		return
 	}
 
@@ -277,17 +279,6 @@ func (b *Bluetooth) init() {
 		logger.Warning(err)
 	}
 
-	// monitor airplane mode enabled state change
-	b.airplaneBltOriginState = make(map[dbus.ObjectPath]bool)
-
-	value := b.getAirplaneBltOriginStateConfig()
-	if value != "" {
-		err := json.Unmarshal([]byte(value), &b.airplaneBltOriginState)
-		if err != nil {
-			logger.Warning(err)
-		}
-	}
-
 	_, err = b.sysBt.ConnectAdapterAdded(func(adapterJSON string) {
 		adapterInfo, err := unmarshalAdapterInfo(adapterJSON)
 		if err != nil {
@@ -481,6 +472,7 @@ func getMprisPlayers(sessionConn *dbus.Conn) ([]string, error) {
 func setAllPlayers(value bool) {
 	sessionConn, err := dbus.SessionBus()
 	if err != nil {
+		logger.Warning(err)
 		return
 	}
 	playerNames, err := getMprisPlayers(sessionConn)
@@ -527,7 +519,7 @@ func (b *Bluetooth) handleBluezPort(value bool) error {
 	logger.Info(" handleBluezPort sinkName : ", sinkName, isBluePort)
 	if isBluePort {
 		//stop music
-		setAllPlayers(value)
+		go setAllPlayers(value)
 	}
 	return nil
 }
@@ -738,6 +730,10 @@ func (b *Bluetooth) doSendFiles(session obex.Session, files []string, totalSize
 		transfer.RemoveAllHandlers()
 		b.emitTransferRemoved(f, transferPath, sessionPath, res)
 
+		if !res {
+			break
+		}
+
 		if cancel {
 			break
 		}
