@@ -15,12 +15,12 @@ import (
 	"sync"
 
 	"github.com/godbus/dbus/v5"
-	dock "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dde.daemon.dock"
-	notification "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.dde.notification"
 	wm "github.com/linuxdeepin/go-dbus-factory/session/com.deepin.wm"
 	clipboard "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.clipboard1"
+	dock "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.daemon.dock1"
 	display "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.display1"
 	launchpad "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.launcher1"
+	notification "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.notification1"
 	sessionmanager "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.sessionmanager1"
 	sessionwatcher "github.com/linuxdeepin/go-dbus-factory/session/org.deepin.dde.sessionwatcher1"
 	daemon "github.com/linuxdeepin/go-dbus-factory/system/org.deepin.dde.daemon1"
