@@ -28,19 +28,21 @@ func run() error {
 	_ = gsettings.StartMonitor()
 
 	serverObj, err := service.NewServerObject(dbusPath, m)
-	err = serverObj.Export()
 	if err != nil {
-		logger.Error("failed to export:", err)
 		return err
 	}
+
 	err = serverObj.SetWriteCallback(m, "Enabled", m.enabledWriteCb)
 	if err != nil {
 		return err
 	}
+	err = serverObj.Export()
+	if err != nil {
+		return err
+	}
 
 	err = service.RequestName(DBusServiceName)
 	if err != nil {
-		logger.Error("failed to request name:", err)
 		return err
 	}
 
