@@ -13,6 +13,7 @@ import (
 	"time"
 
 	"github.com/godbus/dbus/v5"
+	ConfigManager "github.com/linuxdeepin/go-dbus-factory/org.desktopspec.ConfigManager"
 	bluez "github.com/linuxdeepin/go-dbus-factory/system/org.bluez"
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/system/org.freedesktop.login1"
@@ -51,6 +52,14 @@ const (
 	devIconInputMouse      = "input-mouse"
 )
 
+const (
+	dsettingsAppID               = "org.deepin.dde.daemon"
+	dsettingsBluetoothName       = "org.deepin.dde.daemon.bluetooth"
+	dsettingsAutoPairEnableKey   = "autoPairEnable"
+	dsettingsAdapterPowerd       = "adapterPowerd"
+	dsettingsAdapterDiscoverable = "adapterDiscoverable"
+)
+
 //go:generate dbusutil-gen -type SysBluetooth bluetooth.go
 //go:generate dbusutil-gen em -type SysBluetooth,agent
 
@@ -85,11 +94,12 @@ type SysBluetooth struct {
 	// 当发起设备连接成功后，应该把连接的设备添加进设备列表
 	connectedDevices map[dbus.ObjectPath][]*device
 	connectedMu      sync.RWMutex
-	//设备被清空后需要连接的设备路径
+	// 设备被清空后需要连接的设备路径
 	prepareToConnectedDevice dbus.ObjectPath
 	prepareToConnectedMu     sync.Mutex
 	// 升级后第一次进系统，此时需要根据之前有蓝牙连接时，打开蓝牙开关
 	needFixBtPoweredStatus bool
+	canAutoPair            func() bool
 
 	// nolint
 	signals *struct {
@@ -108,7 +118,7 @@ func newSysBluetooth(service *dbusutil.Service) (b *SysBluetooth) {
 	sysBus := service.Conn()
 	b = &SysBluetooth{
 		service:                service,
-		sigLoop:                dbusutil.NewSignalLoop(sysBus, 10),
+		sigLoop:                dbusutil.NewSignalLoop(sysBus, 100),
 		userAgents:             newUserAgentMap(),
 		needFixBtPoweredStatus: false,
 	}
@@ -207,6 +217,49 @@ func (b *SysBluetooth) init() {
 		logger.Warning(err)
 	}
 
+	ds := ConfigManager.NewConfigManager(b.sigLoop.Conn())
+
+	dsBluetoothPath, err := ds.AcquireManager(0, dsettingsAppID, dsettingsBluetoothName, "")
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	dsBluetooth, err := ConfigManager.NewManager(b.sigLoop.Conn(), dsBluetoothPath)
+	if err != nil {
+		logger.Warning(err)
+		return
+	}
+
+	b.canAutoPair = func() bool {
+		v, err := dsBluetooth.Value(0, dsettingsAutoPairEnableKey)
+		if err != nil {
+			logger.Warning(err)
+			return true
+		}
+		return v.Value().(bool)
+	}
+
+	logger.Info("====== dsg autoPairEnable is ======", b.canAutoPair())
+
+	adapterDefaultPowered = func() bool {
+		v, err := dsBluetooth.Value(0, dsettingsAdapterPowerd)
+		if err != nil {
+			logger.Warning(err)
+			return false
+		}
+		return v.Value().(bool)
+	}()
+
+	adapterDefaultDiscoverable = func() bool {
+		v, err := dsBluetooth.Value(0, dsettingsAdapterDiscoverable)
+		if err != nil {
+			logger.Warning(err)
+			return true
+		}
+		return v.Value().(bool)
+	}()
+
 	b.loginManager.InitSignalExt(b.sigLoop, true)
 	_, err = b.loginManager.ConnectSessionNew(b.handleSessionNew)
 
@@ -291,17 +344,18 @@ func (b *SysBluetooth) handleSessionNew(sessionId string, sessionPath dbus.Objec
 
 func (b *SysBluetooth) handlePrepareForSleep(beforeSleep bool) {
 	if beforeSleep {
+		b.stopDiscovery()
 		logger.Debug("prepare to sleep")
 		return
 	}
 	logger.Debug("Wakeup from sleep, will set adapter and try connect device")
 	time.AfterFunc(time.Second*3, func() {
-		//for _, adapter := range b.adapters {
+		// for _, adapter := range b.adapters {
 		//	if !adapter.Powered {
 		//		continue
 		//	}
 		//	//_ = adapter.core.Adapter().Discoverable().Set(0, b.config.Discoverable)
-		//}
+		// }
 		b.tryConnectPairedDevices("")
 	})
 }
@@ -483,7 +537,7 @@ func (b *SysBluetooth) updateBatteryForAdd(devPath dbus.ObjectPath) {
 		b.addDeviceWithCount(devPath, 3)
 	} else {
 		d, _ := b.getDevice(devPath)
-		d.Battery, _ = d.core.Percentage().Get(0)
+		d.Battery, _ = d.core.Battery().Percentage().Get(0)
 
 		// update backup battery
 		b.backupDevicesMu.Lock()
@@ -831,7 +885,7 @@ func (b *SysBluetooth) updateState() {
 
 	for _, devices := range b.devices {
 		for _, d := range devices {
-			if d.connected && d.Paired {
+			if d.adapter != nil && d.adapter.Powered && d.connected && d.Paired {
 				newState = StateConnected
 				break
 			}
@@ -865,6 +919,17 @@ func (b *SysBluetooth) getDevices(adapterPath dbus.ObjectPath) []*device {
 }
 
 func (b *SysBluetooth) tryConnectPairedDevices(adapterPath dbus.ObjectPath) {
+	if b.canAutoPair != nil {
+		if !b.canAutoPair() {
+			logger.Info("can't auto pair beacuse autoPairEnable key is unable")
+			return
+		}
+	} else {
+		return
+	}
+
+	b.setAutoConnectFinishedStatus(adapterPath, false)
+
 	inputOnly := true
 	// 自动连接时长
 	defaultConnectDuration := 2 * time.Minute
@@ -902,7 +967,7 @@ func (b *SysBluetooth) tryConnectPairedDevices(adapterPath dbus.ObjectPath) {
 				logger.Debugf("do not auto connect %v, but try connect once", d)
 				connectDuration = 1 * time.Second
 				if !d.Trusted {
-					err := d.core.Trusted().Set(0, true)
+					err := d.core.Device().Trusted().Set(0, true)
 					if err != nil {
 						logger.Warning(err)
 					}
@@ -921,6 +986,7 @@ func (b *SysBluetooth) tryConnectPairedDevices(adapterPath dbus.ObjectPath) {
 			})
 			priority++
 		}
+		b.setAutoConnectFinishedStatus(adapterPath, false)
 		b.acm.addDevices(adapterPath, deviceInfos, activeReconnectDevices)
 	}
 }
@@ -1062,3 +1128,37 @@ func (b *SysBluetooth) findFirstConnectedDeviceByIcon(icon string) *device {
 	}
 	return nil
 }
+
+func (b *SysBluetooth) setAutoConnectFinishedStatus(adapterPath dbus.ObjectPath, status bool) {
+	adapter, err := b.getAdapter(adapterPath)
+	if err != nil {
+		// 可能是适配器被移除了
+		logger.Warningf("call getAdapter failed; adapterPath:[%s] err:[%s]", adapterPath, err)
+		return
+	}
+
+	if !adapter.Powered {
+		// 适配器电源关闭了
+		logger.Warningf("adapter： [%s] is power off", adapterPath)
+		return
+	}
+	adapter.autoConnectFinished = status
+
+	return
+}
+
+func (b *SysBluetooth) stopDiscovery() {
+	b.adaptersMu.Lock()
+	defer b.adaptersMu.Unlock()
+
+	for _, adapter := range b.adapters {
+		if adapter.Discovering {
+			err := adapter.core.Adapter().StopDiscovery(0)
+			if err != nil {
+				logger.Warning(err)
+			}
+		}
+	}
+
+	return
+}
